@@ -5,7 +5,7 @@ from subprocess import Popen, PIPE, STDOUT
 
 from ringbuffer import RingBuffer
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 
 class What(Popen):
@@ -13,7 +13,7 @@ class What(Popen):
 
     def __init__(self, *args):
         super(What, self).__init__(args, stdout=PIPE, stderr=STDOUT,
-                                   bufsize=1, close_fds=True)
+                                   bufsize=0, close_fds=True)
         self.timeout = 10
         self.queue = Queue()
         self.lines = RingBuffer(100)
@@ -65,6 +65,7 @@ class WhatError(Exception):
         super(WhatError, self).__init__(what_object, expectation)
         self.what = what_object
         self.expectation = expectation
+        self.lines = list(what_object.lines)
 
     def __str__(self):
         return "\nExpected: %r\n" \
@@ -75,4 +76,4 @@ class WhatError(Exception):
                self.expectation,
                self.what.returncode,
                "=" * 70,
-               '\n'.join(self.what.lines))
+               '\n'.join(self.lines))
